==> kit-vue-1.16.12.tgz: package/src/stories/ShActionBar.stories.js <==
/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  number,
} from '@storybook/addon-knobs';
import VueI18n from 'vue-i18n'
import i18n from '../../config/storybook/locale';

import ShActionBarLayout from '../components/sh-action-bar-layout/ShActionBarLayout.vue'
import ShInput from '../components/sh-input/ShInput';

const stories = storiesOf('Action bar layout', module);

stories.addDecorator(withKnobs)
stories.add('ShActionBarLayout', () => ({
  components: {ShActionBarLayout, ShInput},
  i18n: i18n,
  data: () => {
    return {
      showSelections: boolean('showSelections', true),
      show: boolean('show', true), // The first param of the knob function has to be exactly the same as the component input.
      disabledSubmit: boolean('disabledSubmit', false), // The first param of the knob function has to be exactly the same as the component input.
      cancelLabel: text('cancelLabel', 'Cancel'),
      saveLabel: text('saveLabel', 'Save'),
      selectedItems: number('selectedItems', 1),
    }
  },
    template: `
      <div style="
        width: 100%;
        position: fixed;
        left: 0;
      ">
        <ShActionBarLayout
          style="width: 100%; margin-left: 0;"
          :show='show'
          :showSelections='showSelections'
          :cancelLabel='cancelLabel'
          :saveLabel='saveLabel'
          :disabledSubmit='disabledSubmit'
          :selectedItems='selectedItems'
        >
        <div class="sh-action-types" slot="action_types">
          <multiselect
            placeholder="Choose"
            :showLabels="false"
            :options="['Option 1', 'Option 2']"
            :searchable="false"
            :allow-empty="false">
          </multiselect>
          <ShInput></ShInput>
        </div>
        </ShActionBarLayout>
      </div>`,
    methods: {action: action('clicked')}
  }),{
    notes: 'A very simple component',
  });

==> kit-vue-2.3.8.tgz: package/src/stories/ShActionBar.stories.js <==
/* eslint-disable import/no-extraneous-dependencies */
import {storiesOf} from '@storybook/vue'
import {action} from '@storybook/addon-actions'
import {
  withKnobs,
  text,
  boolean,
  select,
  number,
} from '@storybook/addon-knobs';
import i18n from '../../config/storybook/locale';

import ShActionBarLayout from '../components/sh-action-bar-layout/ShActionBarLayout.vue'
import ShInput from '../components/sh-input/ShInput';

const stories = storiesOf('Action bar', module);

stories.addDecorator(withKnobs);
stories.add('ShActionBarLayout', () => {
  return {
    components: {ShActionBarLayout, ShInput},
    i18n: i18n,
    props: {
      showSelections: { default: boolean('showSelections', true) },
      show: { default: boolean('show', true) }, // The first param of the knob function has to be exactly the same as the component input.
      disabledSubmit: { default: boolean('disabledSubmit', false) }, // The first param of the knob function has to be exactly the same as the component input.
      cancelLabel: { default: text('cancelLabel', 'Cancel') },
      saveLabel: { default: text('saveLabel', 'Save') },
      selectedItems: { default: number('selectedItems', 1) }
    },
    template: `
      <div style="
        width: 100%;
        position: fixed;
        left: 0;
      ">
        <ShActionBarLayout
          style="width: 100%; margin-left: 0;"
          :show='show'
          :showSelections='showSelections'
          :cancelLabel='cancelLabel'
          :saveLabel='saveLabel'
          :disabledSubmit='disabledSubmit'
          :selectedItems='selectedItems'
        >
        <div class="sh-action-types" slot="action_types">
          <multiselect
            placeholder="Choose"
            :showLabels="false"
            :options="['Option 1', 'Option 2']"
            :searchable="false"
            :allow-empty="false">
          </multiselect>
          <ShInput></ShInput>
        </div>
        </ShActionBarLayout>
      </div>`,
    methods: {action: action('clicked')}
  }
}, {
  notes: 'A very simple component',
});
